@@ -148,32 +148,32 @@ class PatrowlHearsApi:
             if attr == 'cpes':
                 data.update({'cpes': vuln['cpes']})
 
-            if attr == 'access_authentication'
+            if attr == 'access_authentication':
                 if vuln['access_authentication'] in VULN_ATTRS['access_authentication']['values']:
                     data.update({'access_authentication': vuln['access_authentication']})
                 else:
                     data.update({'access_authentication': VULN_ATTRS['access_authentication']['default']})
-            if attr == 'access_complexity'
+            if attr == 'access_complexity':
                 if vuln['access_complexity'] in VULN_ATTRS['access_complexity']['values']:
                     data.update({'access_complexity': vuln['access_complexity']})
                 else:
                     data.update({'access_complexity': VULN_ATTRS['access_complexity']['default']})
-            if attr == 'access_vector'
+            if attr == 'access_vector':
                 if vuln['access_vector'] in VULN_ATTRS['access_vector']['values']:
                     data.update({'access_vector': vuln['access_vector']})
                 else:
                     data.update({'access_vector': VULN_ATTRS['access_vector']['default']})
-            if attr == 'impact_confidentiality'
+            if attr == 'impact_confidentiality':
                 if vuln['impact_confidentiality'] in VULN_ATTRS['impact_confidentiality']['values']:
                     data.update({'impact_confidentiality': vuln['impact_confidentiality']})
                 else:
                     data.update({'impact_confidentiality': VULN_ATTRS['impact_confidentiality']['default']})
-            if attr == 'impact_integrity'
+            if attr == 'impact_integrity':
                 if vuln['impact_integrity'] in VULN_ATTRS['impact_integrity']['values']:
                     data.update({'impact_integrity': vuln['impact_integrity']})
                 else:
                     data.update({'impact_integrity': VULN_ATTRS['impact_integrity']['default']})
-            if attr == 'impact_availability'
+            if attr == 'impact_availability':
                 if vuln['impact_availability'] in VULN_ATTRS['impact_availability']['values']:
                     data.update({'impact_availability': vuln['impact_availability']})
                 else:
